@@ -8,6 +8,7 @@ import tempfile
 import zipfile
 import subprocess
 import os
+import sys
 import pickle
 import warnings
 
@@ -366,7 +367,7 @@ def compute_control_statistics(
     Returns
     -------
     pypgx.Archive
-        Archive object with the semantic type SampleTable[Statistcs].
+        Archive object with the semantic type SampleTable[Statistics].
     """
     gene_table = core.load_gene_table()
 
@@ -386,15 +387,11 @@ def compute_control_statistics(
     if bed:
         metadata['Platform'] = 'Targeted'
         bf = pybed.BedFrame.from_file(bed)
-        if bf.has_chr_prefix:
-            bed_prefix = 'chr'
-        else:
-            bed_prefix = ''
-        if bam_prefix and bed_prefix:
+        if cf.has_chr_prefix and bf.has_chr_prefix:
             pass
-        elif not bam_prefix and not bed_prefix:
+        elif not cf.has_chr_prefix and not bf.has_chr_prefix:
             pass
-        elif bam_prefix and not bed_prefix:
+        elif cf.has_chr_prefix and not bf.has_chr_prefix:
             bf = bf.update_chr_prefix(mode='add')
         else:
             bf = bf.update_chr_prefix(mode='remove')
@@ -426,7 +423,7 @@ def compute_copy_number(
     ----------
     read_depth : str or pypgx.Archive
         Archive file or object with the semantic type CovFrame[ReadDepth].
-    control_statistcs : str or pypgx.Archive
+    control_statistics : str or pypgx.Archive
         Archive file or object with the semandtic type
         SampleTable[Statistics].
     samples_without_sv : list, optional
@@ -509,28 +506,24 @@ def compute_target_depth(
 
     region = core.get_region(gene, assembly=assembly)
 
-    data = pycov.CovFrame.from_bam(bams, regions=region, zero=True)
+    cf = pycov.CovFrame.from_bam(bams, regions=region, zero=True)
 
     if bed:
         metadata['Platform'] = 'Targeted'
         bf = pybed.BedFrame.from_file(bed)
-        if any(['chr' in x for x in bf.contigs]):
-            bed_prefix = 'chr'
-        else:
-            bed_prefix = ''
-        if bam_prefix and bed_prefix:
+        if cf.has_chr_prefix and bf.has_chr_prefix:
             pass
-        elif not bam_prefix and not bed_prefix:
+        elif not cf.has_chr_prefix and not bf.has_chr_prefix:
             pass
-        elif bam_prefix and not bed_prefix:
+        elif cf.has_chr_prefix and not bf.has_chr_prefix:
             bf = bf.update_chr_prefix(mode='add')
         else:
             bf = bf.update_chr_prefix(mode='remove')
-        data = data.mask_bed(bf, opposite=True)
+        cf = cf.mask_bed(bf, opposite=True)
     else:
         metadata['Platform'] = 'WGS'
 
-    archive = sdk.Archive(metadata, data)
+    archive = sdk.Archive(metadata, cf)
 
     return archive
 
@@ -1184,7 +1177,7 @@ def predict_cnv(copy_number, cnv_caller=None):
     return sdk.Archive(metadata, data)
 
 def prepare_depth_of_coverage(
-    bams, assembly='GRCh37', bed=None
+    bams, assembly='GRCh37', bed=None, genes=None, exclude=False
 ):
     """
     Prepare a depth of coverage file for all target genes with SV from BAM
@@ -1208,6 +1201,10 @@ def prepare_depth_of_coverage(
         Note that the 'chr' prefix in contig names (e.g. 'chr1' vs. '1') will
         be automatically added or removed as necessary to match the input
         BAM's contig names.
+    genes : list, optional
+        List of genes to include.
+    exclude : bool, default: False
+        Exclude specified genes. Ignored when ``genes=None``.
 
     Returns
     -------
@@ -1220,7 +1217,8 @@ def prepare_depth_of_coverage(
     }
 
     regions = create_regions_bed(
-        merge=True, sv_genes=True, assembly=assembly,
+        merge=True, sv_genes=True, assembly=assembly, genes=genes,
+        exclude=exclude
     ).to_regions()
 
     cf = pycov.CovFrame.from_bam(bams, regions=regions, zero=True)
@@ -1228,15 +1226,11 @@ def prepare_depth_of_coverage(
     if bed:
         metadata['Platform'] = 'Targeted'
         bf = pybed.BedFrame.from_file(bed)
-        if any(['chr' in x for x in bf.contigs]):
-            bed_prefix = 'chr'
-        else:
-            bed_prefix = ''
-        if bam_prefix and bed_prefix:
+        if cf.has_chr_prefix and bf.has_chr_prefix:
             pass
-        elif not bam_prefix and not bed_prefix:
+        elif not cf.has_chr_prefix and not bf.has_chr_prefix:
             pass
-        elif bam_prefix and not bed_prefix:
+        elif cf.has_chr_prefix and not bf.has_chr_prefix:
             bf = bf.update_chr_prefix(mode='add')
         else:
             bf = bf.update_chr_prefix(mode='remove')
@@ -1246,6 +1240,33 @@ def prepare_depth_of_coverage(
 
     return sdk.Archive(metadata, cf)
 
+def print_data(input):
+    """
+    Print the main data of specified archive.
+
+    Parameters
+    ----------
+    input : pypgx.Archive
+        Archive file.
+    """
+    archive = sdk.Archive.from_file(input)
+    if 'SampleTable' in archive.type:
+        data = archive.data.to_csv(sep='\t')
+    elif 'CovFrame' in archive.type:
+        data = archive.data.to_string()
+    elif 'VcfFrame' in archive.type:
+        data = archive.data.to_string()
+    else:
+        raise ValueError(f"Data cannot be printed for {archive.type}")
+
+    # https://docs.python.org/3/library/signal.html#note-on-sigpipe
+    try:
+        print(data, end='')
+    except BrokenPipeError:
+        devnull = os.open(os.devnull, os.O_WRONLY)
+        os.dup2(devnull, sys.stdout.fileno())
+        sys.exit(1)
+
 def print_metadata(input):
     """
     Print the metadata of specified archive.
@@ -1260,8 +1281,32 @@ def print_metadata(input):
     with zf.open(f'{parent}/metadata.txt') as f:
         print(f.read().decode('utf-8').strip())
 
+def slice_bam(
+    input, output, assembly='GRCh37', genes=None, exclude=False
+):
+    """
+    Slice BAM file for all genes used by PyPGx.
+
+    Parameters
+    ----------
+    input
+        Input BAM file. It must be already indexed to allow random access.
+    output : str
+        Output BAM file.
+    assembly : {'GRCh37', 'GRCh38'}, default: 'GRCh37'
+        Reference genome assembly.
+    genes : list, optional
+        List of genes to include.
+    exclude : bool, default: False
+        Exclude specified genes. Ignored when ``genes=None``.
+    """
+    bf = create_regions_bed(merge=True, assembly=assembly,
+        genes=genes, exclude=exclude)
+    pybam.slice(input, bf, path=output)
+
 def test_cnv_caller(
-    cnv_caller, copy_number, cnv_calls, confusion_matrix=None
+    cnv_caller, copy_number, cnv_calls, confusion_matrix=None,
+    comparison_table=None
 ):
     """
     Test a CNV caller for the target gene.
@@ -1277,6 +1322,9 @@ def test_cnv_caller(
     confusion_matrix : str, optional
         Write the confusion matrix as a CSV file where rows indicate actual
         class and columns indicate prediction class.
+    comparison_table : str, optional
+        Write a CSV file comparing actual vs. predicted CNV calls for each
+        sample.
     """
     if isinstance(cnv_caller, str):
         cnv_caller = sdk.Archive.from_file(cnv_caller)
@@ -1304,7 +1352,8 @@ def test_cnv_caller(
     code2name = dict(zip(code, cnv_table.Name))
     name2code = dict(zip(cnv_table.Name, code))
     cnv_calls.data['Code'] = cnv_calls.data.apply(lambda r: name2code[r.CNV], axis=1)
-    columns = ['Chromosome', 'Position'] + cnv_calls.data.Sample.to_list()
+    samples = cnv_calls.data.index.to_list()
+    columns = ['Chromosome', 'Position'] + samples
     copy_number.data.df = copy_number.data.df[columns]
     X = copy_number.data.df.iloc[:, 2:].T.to_numpy()
     Y = cnv_calls.data['Code'].to_numpy()
@@ -1312,16 +1361,24 @@ def test_cnv_caller(
     results = predictions == Y
     print(f'Accuracy: {sum(results)/len(Y):.3f} ({sum(results)}/{len(Y)})')
 
+    Y = [code2name[x] for x in Y]
+    predictions = [code2name[x] for x in predictions]
+
     if confusion_matrix is not None:
-        Y = [code2name[x] for x in Y]
-        predictions = [code2name[x] for x in predictions]
         labels = cnv_table.Name.to_list()
         df = pd.DataFrame(metrics.confusion_matrix(Y, predictions, labels=labels))
         df.columns = labels
         df.index = labels
         df.to_csv(confusion_matrix)
 
-def train_cnv_caller(copy_number, cnv_calls, confusion_matrix=None):
+    if comparison_table is not None:
+        df = pd.DataFrame({'Sample': samples, 'Actual': Y,
+            'Predicted': predictions, 'Identical': results})
+        df.to_csv(comparison_table, index=False)
+
+def train_cnv_caller(
+    copy_number, cnv_calls, confusion_matrix=None, comparison_table=None
+):
     """
     Train a CNV caller for the target gene.
 
@@ -1337,6 +1394,9 @@ def train_cnv_caller(copy_number, cnv_calls, confusion_matrix=None):
     confusion_matrix : str, optional
         Write the confusion matrix as a CSV file where rows indicate actual
         class and columns indicate prediction class.
+    comparison_table : str, optional
+        Write a CSV file comparing actual vs. predicted CNV calls for each
+        sample.
 
     Returns
     -------
@@ -1364,7 +1424,8 @@ def train_cnv_caller(copy_number, cnv_calls, confusion_matrix=None):
     code2name = dict(zip(code, cnv_table.Name))
     name2code = dict(zip(cnv_table.Name, code))
     cnv_calls.data['Code'] = cnv_calls.data.apply(lambda r: name2code[r.CNV], axis=1)
-    columns = ['Chromosome', 'Position'] + cnv_calls.data.Sample.to_list()
+    samples = cnv_calls.data.index.to_list()
+    columns = ['Chromosome', 'Position'] + samples
     copy_number.data.df = copy_number.data.df[columns]
     X = copy_number.data.df.iloc[:, 2:].T.to_numpy()
     Y = cnv_calls.data['Code'].to_numpy()
@@ -1375,13 +1436,19 @@ def train_cnv_caller(copy_number, cnv_calls, confusion_matrix=None):
     results = predictions == Y
     print(f'Accuracy: {sum(results)/len(Y):.3f} ({sum(results)}/{len(Y)})')
 
+    Y = [code2name[x] for x in Y]
+    predictions = [code2name[x] for x in predictions]
+
     if confusion_matrix is not None:
-        Y = [code2name[x] for x in Y]
-        predictions = [code2name[x] for x in predictions]
         labels = cnv_table.Name.to_list()
         df = pd.DataFrame(metrics.confusion_matrix(Y, predictions, labels=labels))
         df.columns = labels
         df.index = labels
         df.to_csv(confusion_matrix)
 
+    if comparison_table is not None:
+        df = pd.DataFrame({'Sample': samples, 'Actual': Y,
+            'Predicted': predictions, 'Identical': results})
+        df.to_csv(comparison_table, index=False)
+
     return sdk.Archive(metadata, model)
